@@ -2,12 +2,8 @@ import os
 from datetime import datetime
 import time
 from plyer import notification
-import pkgutil
 
 
-def get_icon():
-    return
-
 def check_day_status():
     return 1 <= datetime.today().isoweekday() <= 5
 
@@ -16,7 +12,7 @@ def notifier_weekday(weekend_mess):
     notification.notify(
         title=weekend_mess,
         message="Have a good day",
-        app_icon=r'sea_fishes.ico',
+        app_icon=os.path.join(os.path.dirname(__file__), 'sea_fishes.ico'),
         timeout=60
     )
 
@@ -25,7 +21,7 @@ def notifier_break():
     notification.notify(
         title="Break",
         message="Rest for 10 minutes before continue working",
-        app_icon=r"break.ico",
+        app_icon=os.path.join(os.path.dirname(__file__), 'break.ico'),
         timeout=60*10
     )
     time.sleep(60*10)
@@ -35,7 +31,7 @@ def notifier_lunch():
     notification.notify(
         title="Lunch Time",
         message="Go and eat something delicious",
-        app_icon=r"food.ico",
+        app_icon=os.path.join(os.path.dirname(__file__), 'food.ico'),
         timeout=60*60
     )
     time.sleep(60*60)
@@ -45,7 +41,7 @@ def notifier_end_workday():
     notification.notify(
         title="The end!",
         message="See you tomorrow",
-        app_icon=r"end.ico",
+        app_icon=os.path.join(os.path.dirname(__file__), 'end.ico'),
         timeout=60
     )
     time.sleep(10)
@@ -55,7 +51,6 @@ def notifier_workday(workday_mess, num):
     notification.notify(
         title=workday_mess + f"Session {num}/8",
         message="Work is in progress...",
-        # app_icon=r"sea_fishes.ico",
         app_icon=os.path.join(os.path.dirname(__file__), 'sea_fishes.ico'),
         timeout=60 * 50
     )
